<?PHP
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * This file is part of Uberghey CMS
 *              A content management system with modules, based on wiki syntax
 *
 * Author: Dan Jensen <admin@leinir.dk>
 * Copyright 2003/2004
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * The GNU General Public License is available at: http://www.gnu.org/copyleft/
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

// If the language is English, there is no need to import sitewide i18n, since that's what we're translating from in the first place
if ($language != "en") {
	if (file_exists("$setup_folder/i18n/$language/i18n.inc")) include("$setup_folder/i18n/$language/i18n.inc");
}
//Run through the modules and get their i18n, if available
$fp = opendir("$setup_folder/modules");
while ($file = readdir($fp)) {
	if (file_exists("$setup_folder/modules/$file/i18n.$language.inc")) include("$setup_folder/modules/$file/i18n.$language.inc");
}
closedir($fp);


/* Old i18n stuff {
	//Just to make sure there's actually something in the messages
	if (file_exists("$setup_folder/i18n/en/auth.inc")) include("$setup_folder/i18n/en/auth.inc");
	if (file_exists("$setup_folder/i18n/en/searchmessages.inc")) include("$setup_folder/i18n/en/searchmessages.inc");
	if (file_exists("$setup_folder/i18n/en/theme.inc")) include("$setup_folder/i18n/en/theme.inc");
	if (file_exists("$setup_folder/i18n/en/$page_id.inc")) include("$setup_folder/i18n/en/$page_id.inc");
	
	//Load the messages, but only if the language isn't English (they would have already been loaded above)
	if ($language != "en") {
		if (file_exists("$setup_folder/i18n/$language/auth.inc")) include("$setup_folder/i18n/$language/auth.inc");
		if (file_exists("$setup_folder/i18n/$language/searchmessages.inc")) include("$setup_folder/i18n/$language/searchmessages.inc");
		if (file_exists("$setup_folder/i18n/$language/theme.inc")) include("$setup_folder/i18n/$language/theme.inc");
		if (file_exists("$setup_folder/i18n/$language/$page_id.inc")) include("$setup_folder/i18n/$language/$page_id.inc");
	}
// Old i18n stuff }
*/

/**
 * i18n() - Internationalization function
 *
 * @param thestring	The string that is to be translated. Must be in British English
 * @param needles	An array containing needles to be inserted at ##key## points throughout the string
 *
 * @return string	The translated string or, if there is no translation available, the untranslated string
 */

function i18n($thestring, $needles = "") {
	global $i18nstrings;
	
	if ($i18nstrings[$thestring] != "") {
		$result = $i18nstrings[$thestring];
	} else {
		$result = $thestring;
	}
	
	if (is_array($needles)) {
		foreach($needles as $key => $value) {
			$result = str_replace("##$key##", $value, $result);
		}
	}
	
	return $result;
}

// Help {
$page_help["//<br />
/<br />
txt1<br />
txt2<br />
/<br />
txt3<br />
txt4<br />
txt5<br />
//"] = i18n("Will produce this table:") . "<table><tr><td>txt1</td><td>txt2</td></tr><tr><td>txt3</td><td>txt4</td><td>txt5</td></tr></table>";
$page_help["{txt1||txt2||txt3||txt4}"] = i18n("Will produce an image for the uploaded file txt1, and the picture will be given the title txt2. The picture will be scaled to the width txt3, and floated to txt4 (correct values are left and right)");
$page_help["{txt1||txt2||txt3}"] = i18n("Will produce an image for the uploaded file txt1, and the picture will be given the title txt2. The picture will be floated to txt3 (correct values are left and right)");
$page_help["{txt1||txt2}}"] = i18n("Will produce an image for the uploaded file txt1, and the picture will be given the title txt2 (this will make most browsers show a tooltip)");
$page_help["{{txt1||txt2}}"] = i18n("Will produce a link to an uploaded file txt1 with the title txt2");
$page_help["%%txt1||txt2%%"] = i18n("Will produce a link to the profile page for the user with id txt1, showing it as txt2");
$page_help["%%txt1%%"] = i18n("Will produce a link to the profile page for the user with id txt1, replacing txt1 with the user's full name");
$page_help[":txt1"] = i18n("Will put txt1 in a preformatted format, for example for showing code");
$page_help[">>txt1<br />||txt2"] = i18n("Right aligns txt1 and centers txt2");
$page_help["//txt1//<br />**txt2**<br />__txt3__"] = i18n("These will make the text txt1 emphasized (italic), txt2 bold and txt3 underlined. Please note that emphasized text cannot contain links.");
$page_help["!txt1<br />
!!txt2<br />
!!!txt3<br />
!!!!txt4<br />
!!!!!txt5"] = i18n("When written as the first thing on a line, this will make the line into a header of the level indicated by the number of exclamation marks");
$page_help["[[txt1||txt2||{txt3||txt4||txt5}]]<br />
((txt1||txt2||{txt3||txt4||txt5}))"] = i18n("Will produce links as explained above, but with an image showing in stead (as shown bellow)");
$page_help["[[txt1||txt2||txt3]]"] = i18n("Will produce a link to an external resource txt1 (for example http://uberghey.sf.net/), but show the link at txt3, and with the tooltip txt2");
$page_help["[[txt1||txt2]]"] = i18n("Will produce a link to an external resource txt1 (for example http://uberghey.sf.net/), but show the link as txt2");
$page_help["[[txt1]]"] = i18n("Will produce a link to an external resource txt1 (for example http://uberghey.sf.net/)");
$page_help["(((txt1||txt2)))"] = i18n("Will create a description link, where the text shown would be txt1, and hovering over it with the mouse would show txt2");
$page_help["((txt1||txt2))"] = i18n("Will produce a link to a page with the title txt1, but show the link as txt2");
$page_help["((txt1))"] = i18n("Will produce a link to a page with the title txt1");

$page_help = array_reverse($page_help);

function generate_pagehelp() {
	global $page_help;
	
	$thetexts = array("txt1", "txt2", "txt3", "txt4", "txt5", "txt6", "txt7", "txt8");
 	$thecolours = array("blue", "red", "green", "maroon", "purple", "fuchsia", "navy", "teal");
	
	$temp_content = "
	<table>";
	
	foreach($page_help as $key => $value) {
		foreach($thetexts as $key2 => $value2) {
			$key = str_replace($value2, "<span style=\"color: " . $thecolours[$key2] . ";\">$value2</span>", $key);
			$value = str_replace($value2, "<span style=\"color: " . $thecolours[$key2] . ";\">$value2</span>", $value);
		}
		$temp_content .= "
		<tr>
		<td class=\"page_help_term\"><div>$key</div></td>
		<td class=\"page_help_description\"><div>$value</div></td>
		</tr>";
	}
	
	$temp_content .= "
	</table>";
	return $temp_content;
}

function generate_pagehelplink() {
	return "
<script language=\"JavaScript\">
<!--
var state = 'none';

function showhide(layer_ref) {
	if (state == 'block') {
		state = 'none';
	} else {
		state = 'block';
	}
	if (document.all) { //IS IE 4 or 5 (or 6 beta)
		//eval( \\\"document.all.\\\" + layer_ref + \\\".style.display = state\\\");
	}
	if (document.layers) { //IS NETSCAPE 4 or below
		document.layers[layer_ref].display = state;
	}
	if (document.getElementById && !document.all) {
		maxwell_smart = document.getElementById(layer_ref);
		maxwell_smart.style.display = state;
	}
}

document.write('<a class=\\\"command\\\" name=\\\"page_help\\\" href=\\\"javascript://\\\" onClick=\\\"showhide(\'page_help\')\\\">[" . i18n("Show layout help") . "]</a>')
document.write('<div id=\"page_help\" style=\"display: none;\">" . str_replace("'", "\'", str_replace("\n", "", str_replace("\"", "\\\"", generate_pagehelp()))) . "</div>')
// --></script>
<noscript><a class=\"command\" href=\"./index.php?page_id=14\" target=\"_blank\">[" . i18n("Show layout help") . "]</a></noscript>";
}
// Help }

// This really ought to be in auth.php, but we need the i18n function for it... so here it is
$permissionlevels_array = array(
			0 => i18n("All"),
			1 => i18n("Registered users"),
			2 => i18n("Registered users, except blacklisted"),
			3 => i18n("Friends"),
			4 => i18n("Noone"));	

?>